@@ -17,6 +17,9 @@ def main():
     parser.add_argument(
         "-t", "--type", dest="test type", required=True, default='api', choices=['api', 'web', 'ios', 'android'], help="auto test type, api, web, ios, android"
     )
+    parser.add_argument(
+        "-r", "--remote-url", dest="remote url", default=None, help="web test's remote url, eg. http://localhost:4444/wd/hub"
+    )
     if len(sys.argv) == 1:
         # httprunner
         parser.print_help()
@@ -35,6 +38,11 @@ def main():
         # httprunner run -h
         pytest.main(["-h"])
         sys.exit(0)
+    elif (
+        len(sys.argv) == 4 and sys.argv[1] in ["-t", "--type"] and sys.argv[2] in ['api', 'web', 'ios', 'android'] and sys.argv[3] in ["-r", "--remote-url"]
+    ):
+        parser.print_help()
+        sys.exit(0)
 
     extra_args = []
     if len(sys.argv) >= 2:
@@ -49,9 +57,12 @@ def main():
     if sys.argv[2] == "api":
         sys.exit(main_run(extra_args))
     elif sys.argv[2] in ['web', 'ios', 'android']:
+        if len(sys.argv) == 6: ST.REMOTE_URL = sys.argv[4] or None
         ST.LOG_DIR = os.path.join('Results', 'log')
         if not os.path.exists(ST.LOG_DIR): os.makedirs(ST.LOG_DIR)
         sys.exit(pytest.main(extra_args))
+    else:
+        parser.print_help()
 
 
 if __name__ == "__main__":
